# Table of Contents

- [code-for-deploying-sap-leanix-github-agent](<./code-for-deploying-sap-leanix-github-agent.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Code for Deploying the SAP LeanIX GitHub Agent](<./Code-for-Deploying-the-SAP-LeanIX-GitHub-Agent.md>)
  - [Sample Code](<./Code-for-Deploying-the-SAP-LeanIX-GitHub-Agent/Sample-Code.md>)
  - [Environment Variables](<./Code-for-Deploying-the-SAP-LeanIX-GitHub-Agent/Environment-Variables.md>)
